@@ -2,7 +2,7 @@
 
 # Sample:
 # bin/export-model.pl --user carrie --model YisouComments \
-#  --server http://ced02.search.cnb.yahoo.com/openapi \
+#  --server http://resty.eeeeworks.org \
 #  > YisouComments.yml
 
 use strict;
@@ -12,7 +12,7 @@ use Getopt::Long;
 use Encode qw(decode encode);
 
 use lib 'lib';
-use WWW::OpenResty;
+use WWW::OpenResty::Simple;
 use Params::Util qw( _HASH _ARRAY0 );
 use YAML::Syck ();
 use JSON::Syck ();
@@ -31,7 +31,7 @@ $user or die "No user given.\n";
 $model or die "No model given.\n";
 $server or die "No server given.\n";
 
-my $openapi = WWW::OpenResty->new( { server => $server } );
+my $openapi = WWW::OpenResty::Simple->new( { server => $server } );
 
 my $offset = 0;
 my $count = 100;
@@ -48,18 +48,8 @@ while (1) {
     if ($password) {
         $args{password} = $password;
     }
-    my $res = $openapi->get($url, \%args);
-    if (!$res->is_success) {
-        die "$url: ", $res->status_line, "\n";
-    }
-    my $json = $res->content;
-    $json or die "No content found in server's response.\n";
-    $json = decode('utf8', $json);
-    my $data = JSON::Syck::Load($json);
-    if (_HASH($data) && !$data->{success} && $data->{error}) {
-        die "Error from the server: $json\n";
-    }
-    elsif (_ARRAY0($data)) {
+    my $data = $openapi->get($url, \%args);
+    if (_ARRAY0($data)) {
         push @rows, @$data;
         last if @$data < $count;
     }
