@@ -10,7 +10,7 @@ use lib 'lib';
 use Params::Util qw( _HASH _ARRAY0 );
 use YAML::Syck ();
 use JSON::Syck ();
-use WWW::OpenResty;
+use WWW::OpenResty::Simple;
 
 $YAML::Syck::ImplicitUnicode = 1;
 $JSON::Syck::ImplicitUnicode = 1;
@@ -33,19 +33,14 @@ my @rows = @$data;
 
 my $offset = 0;
 my $count = 1;
-my $url = "/=/model/$model/~/~?user=$user";
-if ($password) { $url .= "\&password=$password"; }
-my $openapi = WWW::OpenResty->new( { server => $server } );
-$openapi->delete($url);
+my $openresty = WWW::OpenResty::Simple->new( { server => $server } );
+$openresty->login($user, $password);
+$openresty->delete("/=/model/$model/~/~");
 my $inserted = 0;
 while (1) {
     last if $offset >= $#rows;
     #select(undef, undef, undef, 0.1);
     print STDERR "$offset\t";
-    my $url = "$server/=/model/$model/~/~?user=$user\&offset=$offset\&count=$count\&order_by=id:asc";
-    if ($password) {
-        $url .= '&password=' . $password;
-    }
     my $to = $offset + $count - 1;
     my @elems = @rows[$offset..($to > $#rows ? $#rows : $to)];
     #warn "count: ", scalar(@elems), "\n";
@@ -53,19 +48,12 @@ while (1) {
     $json = encode('UTF-8', $json);
     #warn $json;
 
-    my $res = $openapi->post($json, $url);
-    if (!$res->is_success) {
-        die "$url: ", $res->status_line, "\n";
-    }
-    my $res_json = $res->content;
-    $res_json or die "No content found in server's response.\n";
-    #$res_json = decode('UTF-8', $res_json);
-    my $data = JSON::Syck::Load($res_json);
-    if (_HASH($data) && !$data->{success} && $data->{error}) {
-        warn "Error from the server: $res_json: $json\n";
-    } else {
-        $inserted++;
-    }
+    my $res = $openresty->post(
+        "/=/model/$model/~/~",
+        { offset => $offset, count => $count, order_by => 'id:asc' },
+        $json
+    );
+    $inserted++;
 } continue { $offset += $count }
 
 warn "For tatal $inserted (", scalar(@rows), ") records inserted.\n";
