@@ -129,8 +129,8 @@ sub process_request {
     if ($OpenResty::Config{'frontend.log'}) {
         require Clone;
         #warn "------------------------------------------------\n";
-        warn "$http_meth ", $ENV{REQUEST_URI}, "\n";
-        warn JSON::Syck::Dump(Clone::clone($openresty->{_req_data})), "\n"
+        warn "$http_meth /=/", join("/", @bits), "\n";
+        warn $OpenResty::Dumper->(Clone::clone($openresty->{_req_data})), "\n"
             if $http_meth eq 'POST' or $http_meth eq 'PUT';
     }
 
